// ---------------------------------------------------------------------------------------------------------------------
//	PhotoChrome v5.xx - Atari ST interlaced image reduction framework
//	1991-2012 Douglas Little (d.m.l)
// ---------------------------------------------------------------------------------------------------------------------
//	special thanks to:
//
//		evil@DHS for noticing faults, making additional suggestions & testing ideas
//		Frank B for encouraging me back into Atari land
//		ppera for feedback and suggestions re: stream conversion for his CATA video project
//		Vincent Riviere's port of GCC 4.x.x for MiNT/TOS
//		various members of Atari-Forum for adding their 2p (you know who you are!)
//		*all* users of PhotoChrome, Apex etc. - past and future
// ---------------------------------------------------------------------------------------------------------------------

// ====================================================================
// 	lightweight wrapper for static FreeImage interface
// ====================================================================
//	note: this is here mainly to sandbox FreeImage, in case I decide to pull the plug on it
// ====================================================================

#include "common.h"
#include "config.h"

#include "FreeImage.h"

#include "imagepkg.h"
#include "pcsimage.h"

extern Arguments g_allargs;

// --------------------------------------------------------------------

ImagePkg* ImagePkg::instance_ = 0;

ImagePkg::ImagePkg()
{
	// once-only, on first use
	FreeImage_Initialise(/*load_local_plugins_only=*/TRUE);
	
	// get version info
	version_ = FreeImage_GetVersion();

	if (!g_allargs.quiet)
		printf("opened FreeImage... [%s]\n", version_.c_str());
	
	crm_ = FreeImage_GetCopyrightMessage();
	
	FreeImage_SetOutputMessage(FreeImageErrorHandler_);
}

ImagePkg::~ImagePkg()
{
	FreeImage_DeInitialise();
	if (!g_allargs.quiet)
		printf("closed FreeImage...\n");
}
	
// --------------------------------------------------------------------

FIBITMAP* ImagePkg::read_jpg(const char* const _name)
{
	if (g_allargs.verbose)
		printf("loading jpg: %s\n", _name);
	return FreeImage_Load(FIF_JPEG, _name, JPEG_DEFAULT);
}

FIBITMAP* ImagePkg::read_tga(const char* const _name)
{
	if (g_allargs.verbose)
		printf("loading tga: %s\n", _name);
	return FreeImage_Load(FIF_TARGA, _name, TARGA_LOAD_RGB888);		
}

FIBITMAP* ImagePkg::read_png(const char* const _name)
{
	if (g_allargs.verbose)
		printf("loading png: %s\n", _name);
	return FreeImage_Load(FIF_PNG, _name);		
}
		
bool ImagePkg::write_png(FIBITMAP *_fib, const char* const _name)
{
	BOOL result = FreeImage_Save(FIF_PNG, _fib, _name, PNG_DEFAULT);
	return (result == TRUE);
}

// --------------------------------------------------------------------
